Executor

Struct Executor 

pub struct Executor { /* private fields */ }
Object which holds the state of the work queue and allows queueing tasks to run on the thread pool.

Implementations

Source

impl Executor

pub fn new(concurrency: usize) -> Executor

Instantiates a new work queue and creates the threads to service it.

The threads will exit when the Executor goes out of scope (not yet implemented). In the future, we may have process-level coordination to allow different Executors to share a thread pool, and use per-job concurrency limits.

pub fn exec<TASK, RV>(&self, estimate: usize, task: TASK) -> Promise<RV>
where TASK: FnOnce() -> RV + Send + 'static, RV: Send + 'static,

Queue a job on this work queue.

The estimate is meaningless in isolation but jobs with a higher estimate will be dispatched first, so it should be comparable among jobs that could simultaneously be in the work queue.

Returns a Promise that can be used to wait for completion of the queued work. If the provided task panics, the error will be stored and rethrown when the promise is awaited.