pub struct LineCache { /* private fields */ }Expand description
An object for efficient repeated byte offset to line conversions.
The first time a query is made for a given buffer, an index is constructed storing the line number at 256 byte intervals in the file. Subsequent queries can reuse the index.
This is expected to be a very short-lived object. If the line cache outlives any of the buffers it has been queried against, and future buffers receive the same address range, the line cache will return incorrect results (but will not crash).
Implementations
Sourceimpl LineCache
impl LineCache
Sourcepub fn to_offset(&mut self, buf: &[u8], line: u32) -> usize
pub fn to_offset(&mut self, buf: &[u8], line: u32) -> usize
Map a line to a buffer index. Panics if out of range.