pub enum CommandToken {
Keyword(Span),
String(Span),
}Expand description
An individual symbol in a command, either a string or other keyword.
Variants
Keyword(Span)
A keyword (an identifier or symbol not surrounded in quotes)
String(Span)
A string surrounded by ' or " quotes
Implementations
Sourceimpl CommandToken
impl CommandToken
Sourcepub const fn full_span(self) -> Span
pub const fn full_span(self) -> Span
Get the full span of the token, including exterior quotes.
Sourcepub fn append_unescaped_string(buf: &[u8], span: Span, out: &mut Vec<u8>)
pub fn append_unescaped_string(buf: &[u8], span: Span, out: &mut Vec<u8>)
Remove doubled quote escapes from a CommandToken::String(span).
Sourcepub fn unescape_string(buf: &[u8], span: Span) -> Cow<'_, [u8]>
pub fn unescape_string(buf: &[u8], span: Span) -> Cow<'_, [u8]>
Remove doubled quote escapes from a CommandToken::String(span).