pub struct SymbolDef {
pub name: Token,
pub stype: SymbolType,
pub start: StatementIndex,
pub ordinal: TokenIndex,
}Expand description
Extracted information for a math symbol defined in a segment.
Fields
name: TokenThe character sequence representing the symbol.
stype: SymbolTypeThe type of the statement which introduces the symbol.
start: StatementIndexThe location of the statement which introduces the symbol.
ordinal: TokenIndexIndex of the symbol within its introducing statement.