LineCache

Struct LineCache 

pub struct LineCache { /* private fields */ }
An object for efficient repeated byte offset to line conversions.

The first time a query is made for a given buffer, an index is constructed storing the line number at 256 byte intervals in the file. Subsequent queries can reuse the index.

This is expected to be a very short-lived object. If the line cache outlives any of the buffers it has been queried against, and future buffers receive the same address range, the line cache will return incorrect results (but will not crash).

Implementations

Source

impl LineCache

pub fn to_offset(&mut self, buf: &[u8], line: u32) -> usize

Map a line to a buffer index. Panics if out of range.

pub fn from_offset(&mut self, buf: &[u8], offset: usize) -> (u32, u32)

Map a buffer index to a (line, column) pair.

Panics

Panics if the buffer is larger than 4GiB or if offset is out of range.

pub fn line_end(buf: &[u8], offset: usize) -> usize

Find the offset just after the end of the line (usually the location of a ‘\n’, unless we are at the end of the file).